@@ -51,7 +51,7 @@ def main():
             docs.close()
 
         elif str(sys.argv[command]) == "start":
-            uacs.daemon.run_daemon()
+            uacs.run_daemon()
 
         elif str(sys.argv[command]) == "send_mail":
             uacs.send_mail("test", verbose)
